@@ -79,6 +79,8 @@ LipstikStyleConfig::LipstikStyleConfig(QWidget* parent): QWidget(parent)
 	drawStatusBarFrame = new QCheckBox(i18n("Draw status bar frames"), generalGrp);
 	animateProgressBar = new QCheckBox(i18n("Animate progress bars"), generalGrp);
 	drawFocusRect = new QCheckBox(i18n("Draw colored focus rectangle"), generalGrp);
+	newKickerButtons = new QCheckBox(i18n("Flat taskbar buttons"), generalGrp);
+	flatHeaders = new QCheckBox(i18n("Flat column headers"), generalGrp);
 
 	tabLayout->addWidget(generalGrp,0,0,0);
 
@@ -101,6 +103,7 @@ LipstikStyleConfig::LipstikStyleConfig(QWidget* parent): QWidget(parent)
 	drawToolBarSeparator = new QCheckBox(i18n("Draw toolbar separators"), toolbarGrp);
 	drawToolBarItemSeparator = new QCheckBox(i18n("Draw toolbar item separators"), toolbarGrp);
 	drawToolBarHandle = new QCheckBox(i18n("Draw toolbar handles"), toolbarGrp);
+	largeGap = new QCheckBox(i18n("Larger space between items"), toolbarGrp);
 //	useAlterHandle = new QCheckBox(i18n("Alternate handle style"), toolbarGrp);
 
 	tabLayout->addWidget(toolbarGrp,1,0,0);	
@@ -180,11 +183,11 @@ LipstikStyleConfig::LipstikStyleConfig(QWidget* parent): QWidget(parent)
 	tabWidget->insertTab(page2, i18n("About"));
 
 	lipstikLabel = new QLabel(page2);
-        lipstikLabel->setText(i18n("Lipstik 1.0"));
+        lipstikLabel->setText(i18n("Lipstik 1.3"));
 	lipstikLabel->setFrameStyle( QFrame::StyledPanel | QFrame::Raised );
 
 	authorLabel = new QLabel(page2);
-        authorLabel->setText(i18n("     Copyright 2004 (C) Patrice Tremblay [PaT]"));
+        authorLabel->setText(i18n("     Copyright 2004-2005 (C) Patrice Tremblay [PaT]"));
 
 	authorAddressLabel = new QLabel(page2);
         authorAddressLabel->setText(i18n("      tremblaypatrice@yahoo.fr"));
@@ -256,7 +259,7 @@ LipstikStyleConfig::LipstikStyleConfig(QWidget* parent): QWidget(parent)
 	origKickerHighlight = s.readBoolEntry("/lipstikstyle/Settings/kickerHighlight", true);
 	kickerHighlight->setChecked(origKickerHighlight);
 
-	origScrollBarStyle = s.readEntry("/lipstikstyle/Settings/scrollBarStyle", "ThreeButtonScrollBar");
+	origScrollBarStyle = s.readEntry("/lipstikstyle/Settings/scrollBarStyle", "WindowsStyleScrollBar");
 	scrollBarStyle->setCurrentItem(scrollBarItem(origScrollBarStyle));
 
 	origSliderStyle = s.readEntry("/lipstikstyle/Settings/sliderStyle", "sliderLipstikStyle");
@@ -273,8 +276,19 @@ LipstikStyleConfig::LipstikStyleConfig(QWidget* parent): QWidget(parent)
 	drawToolBarSeparator->setChecked(origDrawToolBarSeparator);
 	origDrawToolBarItemSeparator = s.readBoolEntry("/lipstikstyle/Settings/drawToolBarItemSeparator", true);
 	drawToolBarItemSeparator->setChecked(origDrawToolBarItemSeparator);
+
+	origLargeGap = s.readBoolEntry("/lipstikstyle/Settings/largeGap", false);
+	largeGap->setChecked(origLargeGap);
+
  	origDrawFocusRect = s.readBoolEntry("/lipstikstyle/Settings/drawFocusRect", false);
 	drawFocusRect->setChecked(origDrawFocusRect);
+
+ 	origNewKickerButtons = s.readBoolEntry("/lipstikstyle/Settings/newKickerButtons", false);
+	newKickerButtons->setChecked(origNewKickerButtons);
+
+ 	origFlatHeaders = s.readBoolEntry("/lipstikstyle/Settings/flatHeaders", false);
+	flatHeaders->setChecked(origFlatHeaders);
+
 	origDrawTriangularExpander = s.readBoolEntry("/lipstikstyle/Settings/drawTriangularExpander", true);
 	drawTriangularExpander->setChecked(origDrawTriangularExpander);
 	origInputFocusHighlight = s.readBoolEntry("/lipstikstyle/Settings/inputFocusHighlight", true);
@@ -316,8 +330,15 @@ LipstikStyleConfig::LipstikStyleConfig(QWidget* parent): QWidget(parent)
 
 	connect(animateProgressBar, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
 	connect(drawToolBarSeparator, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
+
+	connect(largeGap, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
+
 	connect(drawToolBarItemSeparator, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
  	connect(drawFocusRect, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
+
+ 	connect(newKickerButtons, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
+ 	connect(flatHeaders, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
+
 	connect(drawTriangularExpander, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
 	connect(inputFocusHighlight, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
 	connect(customOverHighlightColor, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
@@ -343,13 +364,11 @@ LipstikStyleConfig::LipstikStyleConfig(QWidget* parent): QWidget(parent)
 	else
 	 menuStripeColor->setEnabled(false);
 
-//Alternate handles
-//	if ( drawToolBarHandle->isChecked() ) {
-//	    useAlterHandle->setEnabled(true);
-//	} else {
-//	    useAlterHandle->setEnabled(false);
-//	}
-
+//New Kicker Taskbar Button style
+	if ( newKickerButtons->isChecked() ) {
+	    kickerHighlight->setEnabled(false);
+	}
+    
 //Input Focus 
 	if ( inputFocusHighlight->isChecked() )
 	    customFocusHighlightColor->setEnabled(true);
@@ -398,8 +417,15 @@ void LipstikStyleConfig::save()
 
 	s.writeEntry("/lipstikstyle/Settings/animateProgressBar", animateProgressBar->isChecked());
 	s.writeEntry("/lipstikstyle/Settings/drawToolBarSeparator", drawToolBarSeparator->isChecked());
+
+	s.writeEntry("/lipstikstyle/Settings/largeGap", largeGap->isChecked());
+
 	s.writeEntry("/lipstikstyle/Settings/drawToolBarItemSeparator", drawToolBarItemSeparator->isChecked());
  	s.writeEntry("/lipstikstyle/Settings/drawFocusRect", drawFocusRect->isChecked());
+
+ 	s.writeEntry("/lipstikstyle/Settings/newKickerButtons", newKickerButtons->isChecked());
+ 	s.writeEntry("/lipstikstyle/Settings/flatHeaders", flatHeaders->isChecked());
+
 	s.writeEntry("/lipstikstyle/Settings/drawTriangularExpander", drawTriangularExpander->isChecked());
 	s.writeEntry("/lipstikstyle/Settings/inputFocusHighlight", inputFocusHighlight->isChecked());
 	s.writeEntry("/lipstikstyle/Settings/customOverHighlightColor", customOverHighlightColor->isChecked());
@@ -428,13 +454,20 @@ void LipstikStyleConfig::defaults()
 	comboboxColored->setChecked(false);
 	kickerHighlight->setChecked(true);
 	
-	scrollBarStyle->setCurrentItem(2);
+	scrollBarStyle->setCurrentItem(0);
 	sliderStyle->setCurrentItem(1);
 
 	animateProgressBar->setChecked(true);
 	drawToolBarSeparator->setChecked(false);
+
+	largeGap->setChecked(false);
+
 	drawToolBarItemSeparator->setChecked(true);
  	drawFocusRect->setChecked(false);
+
+ 	newKickerButtons->setChecked(false);
+ 	flatHeaders->setChecked(true);
+
 	drawTriangularExpander->setChecked(true);
 	inputFocusHighlight->setChecked(true);
 	customOverHighlightColor->setChecked(false);
@@ -474,11 +507,9 @@ void LipstikStyleConfig::updateChanged()
 	else
 	 menuStripeColor->setEnabled(false);
 
-//Alternate handles
-//	if ( drawToolBarHandle->isChecked() )
-//	 useAlterHandle->setEnabled(true);
-//	else
-//	 useAlterHandle->setEnabled(false);
+//New style kicker taskbar buttons (KDE 3.5)
+	if ( newKickerButtons->isChecked() )
+	 kickerHighlight->setEnabled(false);
 
 //Input Focus
 	if ( inputFocusHighlight->isChecked() ) {
@@ -516,8 +547,13 @@ void LipstikStyleConfig::updateChanged()
 	    (kickerHighlight->isChecked() == origKickerHighlight) &&
 	    
 	    (drawToolBarSeparator->isChecked() == origDrawToolBarSeparator) &&
+	    (largeGap->isChecked() == origLargeGap) &&
 	    (drawToolBarItemSeparator->isChecked() == origDrawToolBarItemSeparator) &&
  	    (drawFocusRect->isChecked() == origDrawFocusRect) &&
+
+ 	    (newKickerButtons->isChecked() == origNewKickerButtons) &&
+ 	    (flatHeaders->isChecked() == origFlatHeaders) &&
+
 	    (drawTriangularExpander->isChecked() == origDrawTriangularExpander) &&
 	    (inputFocusHighlight->isChecked() == origInputFocusHighlight) &&
 	    (customOverHighlightColor->isChecked() == origCustomOverHighlightColor) &&
